# mn_mpl_style

This repository contains custom matplotlib styles to help create consistent, beautiful scientific plots with custom layout, style and colours.

Current version: v0.3

## Base matplotlib vs custom mn_thesis style

![style comparison](https://raw.githubusercontent.com/matt-nagle/mn_mpl_style/refs/heads/main/default_vs_mn_thesis_style.svg)

## Installation

You can install the style package using pip:

```bash
pip install mn_mpl_style
